@@ -19,6 +19,8 @@ def setup(app):
     app.add_directive('spelling', SpellingDirective)
     # Report guesses about correct spelling
     app.add_config_value('spelling_show_suggestions', False, 'env')
+    # Report the whole line that has the error
+    app.add_config_value('spelling_show_whole_line', True, 'env')
     # Set the language for the text
     app.add_config_value('spelling_lang', 'en_US', 'env')
     # Set the language for the tokenizer
